package test.org.springdoc.api.app110;

import javax.validation.constraints.Email;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

import org.hibernate.validator.constraints.CreditCardNumber;


/**
 * The type Person.
 */
public class Person {
	/**
	 * The Id.
	 */
	private long id;

	/**
	 * The First name.
	 */
	private String firstName;

	/**
	 * The Last name.
	 */
	@NotNull
	@NotBlank
	@Size(max = 10)
	private String lastName;

	/**
	 * The Email.
	 */
	@Pattern(regexp = ".+@.+\\..+", message = "Please provide a valid email address")
	private String email;

	/**
	 * The Email 1.
	 */
	@Email()
	private String email1;

	/**
	 * The Age.
	 */
	@Min(18)
	@Max(30)
	private int age;

	/**
	 * The Credit card number.
	 */
	@CreditCardNumber
	private String creditCardNumber;

	/**
	 * Gets credit card number.
	 *
	 * @return the credit card number
	 */
	public String getCreditCardNumber() {
		return creditCardNumber;
	}

	/**
	 * Sets credit card number.
	 *
	 * @param creditCardNumber the credit card number
	 */
	public void setCreditCardNumber(String creditCardNumber) {
		this.creditCardNumber = creditCardNumber;
	}

	/**
	 * Gets id.
	 *
	 * @return the id
	 */
	public long getId() {
		return id;
	}

	/**
	 * Sets id.
	 *
	 * @param id the id
	 */
	public void setId(long id) {
		this.id = id;
	}

	/**
	 * Gets email 1.
	 *
	 * @return the email 1
	 */
	public String getEmail1() {
		return email1;
	}

	/**
	 * Sets email 1.
	 *
	 * @param email1 the email 1
	 */
	public void setEmail1(String email1) {
		this.email1 = email1;
	}

	/**
	 * Gets first name.
	 *
	 * @return the first name
	 */
	@Size(min = 2)
	public String getFirstName() {
		return firstName;
	}

	/**
	 * Sets first name.
	 *
	 * @param firstName the first name
	 */
	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	/**
	 * Gets last name.
	 *
	 * @return the last name
	 */
	public String getLastName() {
		return lastName;
	}

	/**
	 * Sets last name.
	 *
	 * @param lastName the last name
	 */
	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	/**
	 * Gets email.
	 *
	 * @return the email
	 */
	public String getEmail() {
		return email;
	}

	/**
	 * Sets email.
	 *
	 * @param email the email
	 */
	public void setEmail(String email) {
		this.email = email;
	}

	/**
	 * Gets age.
	 *
	 * @return the age
	 */
	public int getAge() {
		return age;
	}

	/**
	 * Sets age.
	 *
	 * @param age the age
	 */
	public void setAge(int age) {
		this.age = age;
	}
}
